import { AsyncDirective } from "lit/async-directive.js";
import { directive } from "lit/directive.js";
import { get, listenForLangChanged } from "../util";
/**
 * A lit directive that updates the translation when the language changes.
 */
export class TranslateDirective extends AsyncDirective {
    constructor() {
        super(...arguments);
        this.langChangedSubscription = null;
        this.getTranslation = (() => "");
    }
    render(key, values, config) {
        this.getTranslation = () => get(key, values, config);
        this.subscribe();
        return this.getTranslation();
    }
    updateTranslation() {
        const translation = this.getTranslation();
        this.setValue(translation);
    }
    subscribe() {
        if (this.langChangedSubscription == null) {
            this.langChangedSubscription = listenForLangChanged(this.updateTranslation.bind(this));
        }
    }
    unsubscribe() {
        if (this.langChangedSubscription != null) {
            this.langChangedSubscription();
        }
    }
    disconnected() {
        this.unsubscribe();
    }
    reconnected() {
        this.subscribe();
    }
}
// Create the directive function
export const translate = directive(TranslateDirective);
//# sourceMappingURL=translate.js.map